Documentation
¶
Overview ¶
get json from stdin and return json with v2 objects and v2 relations
Index ¶
Constants ¶
const ( AppName = "ds-load-auth0" AppDescription = "auth0 directory loader" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CLI ¶
type CLI struct {
Config kong.ConfigFlag `help:"Configuration file path" short:"c"`
Version VersionCmd `cmd:"" help:"version information"`
Fetch FetchCmd `cmd:"" help:"fetch auth0 data"`
Transform TransformCmd `cmd:"" help:"transform auth0 data"`
ExportTransform ExportTransformCmd `cmd:"" help:"export default transform template"`
Exec ExecCmd `cmd:"" help:"fetch and transform auth0 data" default:"withargs"`
Verbosity int `short:"v" type:"counter" help:"Use to increase output verbosity."`
Verify VerifyCmd `cmd:"verify" help:"verify fetcher configuration and credentials"`
}
type ExecCmd ¶
type ExecCmd struct {
FetchCmd
TransformCmd
}
type ExportTransformCmd ¶
type ExportTransformCmd struct{}
type FetchCmd ¶
type FetchCmd struct {
Domain string `name:"domain" short:"d" env:"AUTH0_DOMAIN" help:"auth0 domain" required:""`
ClientID string `name:"client-id" short:"i" env:"AUTH0_CLIENT_ID" help:"auth0 client id" required:""`
ClientSecret string `name:"client-secret" short:"s" env:"AUTH0_CLIENT_SECRET" help:"auth0 client secret" required:""`
ConnectionName string `name:"connection-name" env:"AUTH0_CONNECTION_NAME" help:"auth0 connection name" optional:""`
UserPID string `name:"user-pid" env:"AUTH0_USER_PID" help:"auth0 user PID of the user you want to read" optional:""`
UserEmail string `name:"user-email" env:"AUTH0_USER_EMAIL" help:"auth0 user email of the user you want to read" optional:""`
Roles bool `name:"roles" env:"AUTH0_ROLES" default:"false" negatable:"" help:"include roles"`
Orgs bool `name:"orgs" env:"AUTH0_ORGS" default:"false" negatable:"" help:"include organizations"`
RateLimit bool `name:"rate-limit" default:"true" help:"enable http client rate limiter" negatable:""`
SAML bool `name:"saml" default:"false" help:"use SAML data loader"`
}
type TransformCmd ¶
type TransformCmd struct {
Template string `name:"template" short:"t" env:"DS_TEMPLATE_FILE" help:"transformation template file path" type:"path" optional:""`
}
type VersionCmd ¶
type VersionCmd struct{}
func (*VersionCmd) Run ¶
func (cmd *VersionCmd) Run() error
Click to show internal directories.
Click to hide internal directories.